Crate teksilo_platform

Crate teksilo_platform 

Re-exports

pub use accessibility_prefs::AccessibilityPreferences;
pub use clipboard::ArboardClipboard;
pub use clipboard::ClipboardBackend;
pub use clipboard::ClipboardHandle;
pub use clipboard::MemoryClipboard;
pub use event_translation::TranslationState;
pub use file_dialog::RfdAsyncBackend;
pub use file_dialog::EventContextFileDialogExt;
pub use file_dialog::FileDialogBackend;
pub use file_dialog::FileDialogEventPayload;
pub use file_dialog::FileDialogHandle;
pub use file_dialog::FileDialogRequest;
pub use file_dialog::FileDialogResult;
pub use file_dialog::FileFilter;
pub use file_dialog::MemoryFileDialog;
pub use file_dialog::RequestId;
pub use title_bar_host::create_title_bar_host;
pub use window::FrameOutcome;
pub use window::PlatformWindow;
pub use window_system::WindowSystem;
pub use window_system::active_window_system;
pub use window_system::attach_child_window;
pub use window_system::supports_native_modal_windows;
pub use window_system::window_system_for_display_handle;

Modules

accessibility_prefs
OS-level accessibility preference detection.
clipboard
System clipboard abstraction.
event_translation
external_dnd
External (OS) drag-and-drop service.
file_dialog
Native file-dialog service.
native_menu
Native (OS) menu service.
os_theme
OS theme detection — reads colors directly from desktop environment configuration files and settings.
title_bar_host
Per-platform implementations of teksilo_core::PlatformTitleBarHost.
window
window_activation
Cross-platform window “raise / activate” — the per-OS backend behind WindowState::focus() / WindowOps::focus_window.
window_system
Which windowing system a Linux/BSD session is running on, and what that implies for window chrome and modal windows.
x11
X11 support: the window-manager capability probe behind the custom title bar, and the XDND protocol layer behind external drag-and-drop.