pub enum SoftKeyboardAction {
Nothing,
Ask(bool),
}Expand description
What the framework should do about a pending soft-keyboard request.
Variants
Nothing
Nothing — either the framework has no keyboard request to send, or the request is already satisfied by the IME-allowance reconcile.
Ask(bool)
Ask the platform to show (true) or hide (false) the keyboard.